@@ -31,34 +31,27 @@
 
 K_PLUGIN_CLASS_WITH_JSON(PlasmaVaultFileItemAction, "plasmavaultfileitemaction.json")
 
-PlasmaVaultFileItemAction::PlasmaVaultFileItemAction(QObject* parent, const QVariantList&)
+PlasmaVaultFileItemAction::PlasmaVaultFileItemAction(QObject *parent, const QVariantList &)
     : KAbstractFileItemActionPlugin(parent)
-{}
-
-QList<QAction*> PlasmaVaultFileItemAction::actions(const KFileItemListProperties& fileItemInfos, QWidget* parentWidget)
 {
-    if (fileItemInfos.urlList().size() != 1 ||
-        !fileItemInfos.isDirectory() ||
-            !fileItemInfos.isLocal()) return {};
+}
 
-    QList<QAction*> actions;
+QList<QAction *> PlasmaVaultFileItemAction::actions(const KFileItemListProperties &fileItemInfos, QWidget *parentWidget)
+{
+    if (fileItemInfos.urlList().size() != 1 || !fileItemInfos.isDirectory() || !fileItemInfos.isLocal())
+        return {};
+
+    QList<QAction *> actions;
     const QIcon icon = QIcon::fromTheme(QStringLiteral("plasmavault"));
 
     auto fileItem = fileItemInfos.urlList()[0].toLocalFile();
 
-    auto createAction = [this] (const QIcon& icon, const QString& name,
-                                QString command, QString device,
-                                QWidget* parentWidget)
-    {
+    auto createAction = [this](const QIcon &icon, const QString &name, QString command, QString device, QWidget *parentWidget) {
         QAction *action = new QAction(icon, name, parentWidget);
 
-        connect(action, &QAction::triggered, this, [this,command,device]() {
-            auto method = QDBusMessage::createMethodCall(
-                    "org.kde.kded5",
-                    "/modules/plasmavault",
-                    "org.kde.plasmavault",
-                    command);
-            method.setArguments({ device });
+        connect(action, &QAction::triggered, this, [this, command, device]() {
+            auto method = QDBusMessage::createMethodCall("org.kde.kded5", "/modules/plasmavault", "org.kde.plasmavault", command);
+            method.setArguments({device});
 
             QDBusConnection::sessionBus().call(method, QDBus::NoBlock);
         });
@@ -67,28 +60,20 @@ QList<QAction*> PlasmaVaultFileItemAction::actions(const KFileItemListProperties
     };
 
     KConfig config("plasmavaultrc");
-    for (auto group: config.groupList()) {
+    for (auto group : config.groupList()) {
         auto mountPoint = config.entryMap(group)["mountPoint"];
         if (mountPoint == fileItem) {
             const auto currentMounts = KMountPoint::currentMountPoints();
 
-            const bool mounted = std::any_of(currentMounts.begin(), currentMounts.end(),
-                    [mountPoint] (const KMountPoint::Ptr& mount) {
-                        return mount->mountPoint() == mountPoint;
-                    });
+            const bool mounted = std::any_of(currentMounts.begin(), currentMounts.end(), [mountPoint](const KMountPoint::Ptr &mount) {
+                return mount->mountPoint() == mountPoint;
+            });
 
             const QString command = mounted ? "closeVault" : "openVault";
-            const QString title = mounted ?
-                             i18nc("@action Action to unmount a vault", "Close this Plasma Vault") :
-                             i18nc("@action Action to mount a vault", "Open this Plasma Vault");
+            const QString title = mounted ? i18nc("@action Action to unmount a vault", "Close this Plasma Vault")
+                                          : i18nc("@action Action to mount a vault", "Open this Plasma Vault");
 
-            return {
-                createAction(icon,
-                             title,
-                             command,
-                             group,
-                             parentWidget)
-            };
+            return {createAction(icon, title, command, group, parentWidget)};
         }
     }
 
