@@ -1,29 +1,15 @@
 /*
- *   Copyright 2017 by Kees vd Broek <cryptodude@libertymail.net>
+ *   SPDX-FileCopyrightText: 2017 Kees vd Broek <cryptodude@libertymail.net>
  *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License or (at your option) version 3 or any later version
- *   accepted by the membership of KDE e.V. (or its successor approved
- *   by the membership of KDE e.V.), which shall act as a proxy
- *   defined in Section 14 of version 3 of the license.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 #include "mountdialog.h"
 
+#include <QAction>
 #include <QCloseEvent>
+#include <QMessageBox>
 #include <QStyle>
 #include <QStyleOption>
-#include <QAction>
-#include <QMessageBox>
 
 #include <KMessageWidget>
 
@@ -43,23 +29,21 @@ MountDialog::MountDialog(PlasmaVault::Vault *vault)
     m_detailsAction->setToolTip(i18n("Details..."));
     m_detailsAction->setIcon(QIcon::fromTheme("view-list-details"));
 
-    connect(m_detailsAction, &QAction::triggered,
-            this, [this] {
-                QString message;
-                const auto out = m_lastError.out().trimmed();
-                const auto err = m_lastError.err().trimmed();
+    connect(m_detailsAction, &QAction::triggered, this, [this] {
+        QString message;
+        const auto out = m_lastError.out().trimmed();
+        const auto err = m_lastError.err().trimmed();
 
-                if (!out.isEmpty() && !err.isEmpty()) {
-                    message = i18n("Command output:\n%1\n\nError output: %2", m_lastError.out(), m_lastError.err());
-                } else {
-                    message = out + err;
-                }
+        if (!out.isEmpty() && !err.isEmpty()) {
+            message = i18n("Command output:\n%1\n\nError output: %2", m_lastError.out(), m_lastError.err());
+        } else {
+            message = out + err;
+        }
 
-                auto messageBox = new QMessageBox(QMessageBox::Critical, i18n("Error details"), message, QMessageBox::Ok, this);
-                messageBox->setAttribute(Qt::WA_DeleteOnClose);
-                messageBox->show();
-
-            });
+        auto messageBox = new QMessageBox(QMessageBox::Critical, i18n("Error details"), message, QMessageBox::Ok, this);
+        messageBox->setAttribute(Qt::WA_DeleteOnClose);
+        messageBox->show();
+    });
 
     auto errorLabelSizePolicy = m_errorLabel->sizePolicy();
     errorLabelSizePolicy.setHorizontalPolicy(QSizePolicy::Expanding);
@@ -83,7 +67,7 @@ void MountDialog::accept()
     m_ui.password->lineEdit()->setEchoMode(QLineEdit::Password);
     m_ui.password->lineEdit()->setCursor(Qt::WaitCursor);
     QString pwd = m_ui.password->password();
-    auto future = m_vault->open({ { KEY_PASSWORD, pwd } });
+    auto future = m_vault->open({{KEY_PASSWORD, pwd}});
     const auto result = AsynQt::await(future);
 
     unsetCursor();
@@ -104,7 +88,6 @@ void MountDialog::accept()
 
         } else {
             m_errorLabel->removeAction(m_detailsAction);
-
         }
     }
 }
